@@ -7,7 +7,7 @@ import numpy as np
 import torch
 from PIL import Image
 
-from ultralytics import YOLO
+from ultralytics import RTDETR, YOLO
 from ultralytics.yolo.data.build import load_inference_source
 from ultralytics.yolo.utils import LINUX, ONLINE, ROOT, SETTINGS
 
@@ -51,6 +51,7 @@ def test_predict_img():
     model = YOLO(MODEL)
     seg_model = YOLO('yolov8n-seg.pt')
     cls_model = YOLO('yolov8n-cls.pt')
+    pose_model = YOLO('yolov8n-pose.pt')
     im = cv2.imread(str(SOURCE))
     assert len(model(source=Image.open(SOURCE), save=True, verbose=True)) == 1  # PIL
     assert len(model(source=im, save=True, save_txt=True)) == 1  # ndarray
@@ -64,18 +65,20 @@ def test_predict_img():
         cv2.imread(str(SOURCE)),  # OpenCV
         Image.open(SOURCE),  # PIL
         np.zeros((320, 640, 3))]  # numpy
-    assert len(model(batch)) == len(batch)  # multiple sources in a batch
+    assert len(model(batch, visualize=True)) == len(batch)  # multiple sources in a batch
 
     # Test tensor inference
     im = cv2.imread(str(SOURCE))  # OpenCV
     t = cv2.resize(im, (32, 32))
     t = torch.from_numpy(t.transpose((2, 0, 1)))
     t = torch.stack([t, t, t, t])
-    results = model(t)
+    results = model(t, visualize=True)
     assert len(results) == t.shape[0]
-    results = seg_model(t)
+    results = seg_model(t, visualize=True)
     assert len(results) == t.shape[0]
-    results = cls_model(t)
+    results = cls_model(t, visualize=True)
+    assert len(results) == t.shape[0]
+    results = pose_model(t, visualize=True)
     assert len(results) == t.shape[0]
 
 
@@ -98,20 +101,20 @@ def test_val_scratch():
 
 def test_amp():
     if torch.cuda.is_available():
-        from ultralytics.yolo.engine.trainer import check_amp
+        from ultralytics.yolo.utils.checks import check_amp
         model = YOLO(MODEL).model.cuda()
         assert check_amp(model)
 
 
 def test_train_scratch():
     model = YOLO(CFG)
-    model.train(data='coco8.yaml', epochs=1, imgsz=32)
+    model.train(data='coco8.yaml', epochs=1, imgsz=32, cache='disk')  # test disk caching
     model(SOURCE)
 
 
 def test_train_pretrained():
     model = YOLO(MODEL)
-    model.train(data='coco8.yaml', epochs=1, imgsz=32)
+    model.train(data='coco8.yaml', epochs=1, imgsz=32, cache='ram')  # test RAM caching
     model(SOURCE)
 
 
@@ -170,8 +173,11 @@ def test_export_paddle(enabled=False):
 
 
 def test_all_model_yamls():
-    for m in list((ROOT / 'models').rglob('*.yaml')):
-        YOLO(m.name)
+    for m in list((ROOT / 'models').rglob('yolo*.yaml')):
+        if m.name == 'yolov8-rtdetr.yaml':  # except the rtdetr model
+            RTDETR(m.name)
+        else:
+            YOLO(m.name)
 
 
 def test_workflow():
@@ -185,7 +191,7 @@ def test_workflow():
 def test_predict_callback_and_setup():
     # test callback addition for prediction
     def on_predict_batch_end(predictor):  # results -> List[batch_size]
-        path, _, im0s, _, _ = predictor.batch
+        path, im0s, _, _ = predictor.batch
         # print('on_predict_batch_end', im0s[0].shape)
         im0s = im0s if isinstance(im0s, list) else [im0s]
         bs = [predictor.dataset.bs for _ in range(len(path))]
@@ -194,7 +200,7 @@ def test_predict_callback_and_setup():
     model = YOLO(MODEL)
     model.add_callback('on_predict_batch_end', on_predict_batch_end)
 
-    dataset = load_inference_source(source=SOURCE, transforms=model.transforms)
+    dataset = load_inference_source(source=SOURCE)
     bs = dataset.bs  # noqa access predictor properties
     results = model.predict(dataset, stream=True)  # source already setup
     for _, (result, im0, bs) in enumerate(results):
@@ -204,32 +210,35 @@ def test_predict_callback_and_setup():
         print(boxes)
 
 
-def test_result():
-    model = YOLO('yolov8n-pose.pt')
-    res = model([SOURCE, SOURCE])
-    res[0].plot(conf=True, boxes=False)
-    res[0].plot(pil=True)
-    res[0] = res[0].cpu().numpy()
-    print(res[0].path, res[0].keypoints)
+def _test_results_api(res):
+    # General apis except plot
+    res = res.cpu().numpy()
+    # res = res.cuda()
+    res = res.to(device='cpu', dtype=torch.float32)
+    res.save_txt('label.txt', save_conf=False)
+    res.save_txt('label.txt', save_conf=True)
+    res.save_crop('crops/')
+    res.tojson(normalize=False)
+    res.tojson(normalize=True)
+    res.plot(pil=True)
+    res.plot(conf=True, boxes=False)
+    res.plot()
+    print(res)
+    print(res.path)
+    for k in res.keys:
+        print(getattr(res, k))
 
-    model = YOLO('yolov8n-seg.pt')
-    res = model([SOURCE, SOURCE])
-    res[0].plot(conf=True, boxes=False, masks=True)
-    res[0].plot(pil=True)
-    res[0] = res[0].cpu().numpy()
-    print(res[0].path, res[0].masks.data)
 
-    model = YOLO('yolov8n.pt')
-    res = model(SOURCE)
-    res[0].plot(pil=True)
-    res[0].plot()
-    res[0] = res[0].cpu().numpy()
-    print(res[0].path)
+def test_results():
+    for m in ['yolov8n-pose.pt', 'yolov8n-seg.pt', 'yolov8n.pt', 'yolov8n-cls.pt']:
+        model = YOLO(m)
+        res = model([SOURCE, SOURCE])
+        _test_results_api(res[0])
 
-    model = YOLO('yolov8n-cls.pt')
-    res = model(SOURCE)
-    res[0].plot(probs=False)
-    res[0].plot(pil=True)
-    res[0].plot()
-    res[0] = res[0].cpu().numpy()
-    print(res[0].path)
+
+def test_track():
+    im = cv2.imread(str(SOURCE))
+    for m in ['yolov8n-pose.pt', 'yolov8n-seg.pt', 'yolov8n.pt']:
+        model = YOLO(m)
+        res = model.track(source=im)
+        _test_results_api(res[0])
